@@ -7,39 +7,33 @@ pc_dist <- c(
 pc_type <- c("Values" = "values", "Probabilities" = "probs")
 
 make_pc_values_input <- function(lb, lb_init = NA, ub, ub_init = 0) {
-  if(!is_empty(r_state[[lb]])) ub_init <- NA
-  if(!is_empty(r_state[[ub]])) lb_init <- NA
-  div(
-    class = "row",
-    div(
-      class = "col-xs-6",
-      numericInput(lb, "Lower bound:", value = state_init(lb, lb_init))
-    ),
-    div(
-      class = "col-xs-6",
-      numericInput(ub, "Upper bound:", value = state_init(ub, ub_init))
-    )
+  if(!radiant.data::is_empty(r_state[[lb]])) ub_init <- NA
+  if(!radiant.data::is_empty(r_state[[ub]])) lb_init <- NA
+  tags$table(
+    tags$td(numericInput(lb, "Lower bound:", value = state_init(lb, lb_init))),
+    tags$td(numericInput(ub, "Upper bound:", value = state_init(ub, ub_init)))
+  )
+}
+
+make_side_by_side <- function(a, b) {
+  tags$table(
+    tags$td(a, width="50%"),
+    tags$td(b, width="50%"),
+    width="100%"
   )
 }
 
 make_pc_prob_input <- function(lb, lb_init = NA, ub, ub_init = 0.95) {
-  if(!is_empty(r_state[[lb]])) ub_init <- NA
-  if(!is_empty(r_state[[ub]])) lb_init <- NA
-  div(
-    class = "row",
-    div(
-      class = "col-xs-6",
-      numericInput(
-        lb, "Lower bound:", value = state_init(lb, lb_init),
-        min = 0, max = 1, step = .005
-      )
+  if(!radiant.data::is_empty(r_state[[lb]])) ub_init <- NA
+  if(!radiant.data::is_empty(r_state[[ub]])) lb_init <- NA
+  make_side_by_side(
+    numericInput(
+      lb, "Lower bound:", value = state_init(lb, lb_init),
+      min = 0, max = 1, step = .005
     ),
-    div(
-      class = "col-xs-6",
-      numericInput( 
-        ub, "Upper bound:", value = state_init(ub, ub_init),
-        min = 0, max = 1, step = .005
-      )
+    numericInput( 
+      ub, "Upper bound:", value = state_init(ub, ub_init),
+      min = 0, max = 1, step = .005
     )
   )
 }
@@ -137,18 +131,10 @@ output$ui_pc_input_chisq <- renderUI({
 })
 
 output$ui_pc_tdist <- renderUI({
-  tagList(
-    numericInput(
-      "pct_df", "Degrees of freedom:",
-      value = state_init("pct_df", 10),
-      min = 3
-    )
-    # , div(class = "row",
-    #     div(class = "col-xs-6", numericInput("pct_mean", label = "Mean:",
-    #                           value = state_init("pct_mean", 0))),
-    #     div(class = "col-xs-6",numericInput("pct_stdev", label = "St. dev:", min = 0,
-    #                          value = state_init("pct_stdev", 1)))
-    # )
+  numericInput(
+    "pct_df", "Degrees of freedom:",
+    value = state_init("pct_df", 10),
+    min = 3
   )
 })
 
@@ -161,24 +147,15 @@ output$ui_pc_input_tdist <- renderUI({
 })
 
 output$ui_pc_norm <- renderUI({
-  tagList(
-    div(
-      class = "row",
-      div(
-        class = "col-xs-6",
-        numericInput(
-          "pc_mean", "Mean:",
-          value = state_init("pc_mean", 0)
-        )
-      ),
-      div(
-        class = "col-xs-6",
-        numericInput(
-          "pc_stdev", "St. dev:",
-          min = 0,
-          value = state_init("pc_stdev", 1)
-        )
-      )
+  make_side_by_side(
+    numericInput(
+      "pc_mean", "Mean:",
+      value = state_init("pc_mean", 0)
+    ),
+    numericInput(
+      "pc_stdev", "St. dev:",
+      min = 0,
+      value = state_init("pc_stdev", 1)
     )
   )
 })
@@ -192,24 +169,15 @@ output$ui_pc_input_norm <- renderUI({
 })
 
 output$ui_pc_lnorm <- renderUI({
-  tagList(
-    div(
-      class = "row",
-      div(
-        class = "col-xs-6",
-        numericInput(
-          "pcln_meanlog", "Mean log:",
-          value = state_init("pcln_meanlog", 0)
-        )
-      ),
-      div(
-        class = "col-xs-6",
-        numericInput(
-          "pcln_sdlog", "St. dev log:",
-          min = 0,
-          value = state_init("pcln_sdlog", 1)
-        )
-      )
+  make_side_by_side(
+    numericInput(
+      "pcln_meanlog", "Mean log:",
+      value = state_init("pcln_meanlog", 0)
+    ),
+    numericInput(
+      "pcln_sdlog", "St. dev log:",
+      min = 0,
+      value = state_init("pcln_sdlog", 1)
     )
   )
 })
@@ -223,24 +191,15 @@ output$ui_pc_input_lnorm <- renderUI({
 })
 
 output$ui_pc_binom <- renderUI({
-  tagList(
-    div(
-      class = "row",
-      div(
-        class = "col-xs-6",
-        numericInput(
-          "pcb_n", label = "n:",
-          value = state_init("pcb_n", 10), min = 0
-        )
-      ),
-      div(
-        class = "col-xs-6",
-        numericInput(
-          "pcb_p", "p:",
-          min = 0, max = 1, step = .005,
-          value = state_init("pcb_p", .2)
-        )
-      )
+  make_side_by_side(
+    numericInput(
+      "pcb_n", label = "n:",
+      value = state_init("pcb_n", 10), min = 0
+    ),
+    numericInput(
+      "pcb_p", "p:",
+      min = 0, max = 1, step = .005,
+      value = state_init("pcb_p", .2)
     )
   )
 })
@@ -254,23 +213,14 @@ output$ui_pc_input_binom <- renderUI({
 })
 
 output$ui_pc_unif <- renderUI({
-  tagList(
-    div(
-      class = "row",
-      div(
-        class = "col-xs-6",
-        numericInput(
-          "pcu_min", "Min:",
-          value = state_init("pcu_min", 0)
-        )
-      ),
-      div(
-        class = "col-xs-6",
-        numericInput(
-          "pcu_max", "Max:",
-          value = state_init("pcu_max", 1)
-        )
-      )
+  make_side_by_side(
+    numericInput(
+      "pcu_min", "Min:",
+      value = state_init("pcu_min", 0)
+    ),
+    numericInput(
+      "pcu_max", "Max:",
+      value = state_init("pcu_max", 1)
     )
   )
 })
@@ -401,7 +351,7 @@ pc_plot_height <- function() 400
 
 pc_args <- reactive({
   pc_dist <- input$pc_dist
-  if (is_empty(pc_dist) || pc_dist == "norm") {
+  if (radiant.data::is_empty(pc_dist) || pc_dist == "norm") {
     as.list(formals(prob_norm))
   } else if (pc_dist == "lnorm") {
     as.list(formals(prob_lnorm))
@@ -427,7 +377,7 @@ pc_args <- reactive({
 ## list of function inputs selected by user
 pc_inputs <- reactive({
   pc_dist <- input$pc_dist
-  if (is_empty(pc_dist) || pc_dist == "norm") {
+  if (radiant.data::is_empty(pc_dist) || pc_dist == "norm") {
     pre <- "pc_"
   } else if (pc_dist == "lnorm") {
     pre <- "pcln_"
@@ -494,7 +444,7 @@ output$prob_calc <- renderUI({
 })
 
 pc_available <- reactive({
-  if (is_empty(input$pc_dist) || is_empty(input$pc_type)) {
+  if (radiant.data::is_empty(input$pc_dist) || radiant.data::is_empty(input$pc_type)) {
     ""
   } else {
     a <- "available"
@@ -527,7 +477,7 @@ pc_available <- reactive({
         a <- "Please provide a value for the degrees of freedom (> 0)"
       }
     } else if (input$pc_dist == "disc") {
-      if (is_empty(input$pcd_v) || is_empty(input$pcd_p)) {
+      if (radiant.data::is_empty(input$pcd_v) || radiant.data::is_empty(input$pcd_p)) {
         a <- "Please provide a set of values and probabilities.\nSeparate numbers using spaces (e.g., 1/2 1/2)"
       }
     } else if (input$pc_dist == "expo") {
@@ -553,17 +503,17 @@ pc_available <- reactive({
 })
 
 .summary_prob_calc <- reactive({
-  type <- if (is_empty(input$pc_type)) "values" else input$pc_type
+  type <- if (radiant.data::is_empty(input$pc_type)) "values" else input$pc_type
   summary(.prob_calc(), type = type)
 })
 
 .plot_prob_calc <- reactive({
   req(pc_available() == "available")
-  type <- if (is_empty(input$pc_type)) "values" else input$pc_type
+  type <- if (radiant.data::is_empty(input$pc_type)) "values" else input$pc_type
   plot(.prob_calc(), type = type)
 })
 
-observeEvent(input$prob_calc_report, {
+prob_calc_report <- function() {
   req(input$pc_dist)
   type <- input$pc_type
   inp <- pc_inputs()
@@ -590,7 +540,7 @@ observeEvent(input$prob_calc_report, {
     fig.width = pc_plot_width(),
     fig.height = pc_plot_height()
   )
-})
+}
 
 download_handler(
   id = "dlp_prob_calc", 
@@ -602,3 +552,18 @@ download_handler(
   width = pc_plot_width,
   height = pc_plot_height
 )
+
+observeEvent(input$prob_calc_report, {
+  r_info[["latest_screenshot"]] <- NULL
+  prob_calc_report()
+})
+
+observeEvent(input$prob_calc_screenshot, {
+  r_info[["latest_screenshot"]] <- NULL
+  radiant_screenshot_modal("modal_prob_calc_screenshot")
+})
+
+observeEvent(input$modal_prob_calc_screenshot, {
+  prob_calc_report()
+  removeModal() ## remove shiny modal after save
+})
\ No newline at end of file
